| Title: | SUIT Cerebellar Lobular Atlas for the 'ggseg' Ecosystem |
|---|---|
| Description: | SUIT cerebellar parcellation into anatomical lobules and deep nuclei for the 'ggseg' ecosystem. Provides a unified 'ggseg_atlas' object with both 2D polygon geometry and 3D vertex indices, for use with 'ggseg' and 'ggseg3d'. |
| Authors: | Athanasia Mo Mowinckel [aut, cre] (ORCID: <https://orcid.org/0000-0002-5756-0223>) |
| Maintainer: | Athanasia Mo Mowinckel <[email protected]> |
| License: | CC0 |
| Version: | 0.0.1 |
| Built: | 2026-05-27 06:30:47 UTC |
| Source: | https://github.com/ggsegverse/ggsegSUIT |
Cerebellar parcellation into anatomical lobules and deep nuclei from the SUIT atlas (Diedrichsen et al., 2009). Contains 2D polygon geometry and 3D meshes.
suit()suit()
A ggseg.formats::ggseg_atlas object (cerebellar).
Diedrichsen J et al. (2009). A probabilistic MR atlas of the human cerebellum. doi:10.1016/j.neuroimage.2009.01.045
suit()suit()